@@ -4,7 +4,15 @@ package Data::Record::Serialize::Encode::dbi;
 
 use Moo::Role;
 
-our $VERSION = '0.11'; # TRIAL
+use Data::Record::Serialize::Error { errors =>
+  [ qw( param
+        connect
+        schema
+        create
+        insert
+   )] }, -all;
+
+our $VERSION = '0.26'; # TRIAL
 
 use Data::Record::Serialize::Types -types;
 
@@ -15,33 +23,19 @@ use Types::Standard -types;
 use List::Util qw[ pairmap ];
 
 use DBI;
-use Carp;
 
 use namespace::clean;
 
-#pod =attr C<dsn>
-#pod
-#pod I<Required> The DBI Data Source Name (DSN) passed to B<L<DBI>>.  It
-#pod may either be a string or an arrayref containing strings or arrayrefs,
-#pod which should contain key-value pairs.  Elements in the sub-arrays are
-#pod joined with C<=>, elements in the top array are joined with C<:>.  For
-#pod example,
-#pod
-#pod   [ 'SQLite', { dbname => $db } ]
-#pod
-#pod is transformed to
-#pod
-#pod   SQLite:dbname=$db
-#pod
-#pod The standard prefix of C<dbi:> will be added if not present.
-#pod
-#pod =cut
+
+
+
+
+
 
 has dsn => (
     is       => 'ro',
     required => 1,
     coerce   => sub {
-
         my $arg = 'ARRAY' eq ref $_[0] ? $_[0] : [ $_[0] ];
         my @dsn;
         for my $el ( @{$arg} ) {
@@ -61,12 +55,18 @@ has dsn => (
     },
 );
 
-#pod =attr C<table>
-#pod
-#pod I<Required> The name of the table in the database which will contain the records.
-#pod It will be created if it does not exist.
-#pod
-#pod =cut
+has _cached => (
+    is       => 'ro',
+    default  => 0,
+    init_arg => 'cached',
+);
+
+
+
+
+
+
+
 
 has table => (
     is       => 'ro',
@@ -74,17 +74,13 @@ has table => (
     required => 1,
 );
 
-#pod =attr C<schema>
-#pod
-#pod The schema to which the table belongs.  Optional.
-#pod
-#pod =begin pod_coverage
-#pod
-#pod =head3 has_schema
-#pod
-#pod =end pod_coverage
-#pod
-#pod =cut
+
+
+
+
+
+
+
 
 
 has schema => (
@@ -93,11 +89,11 @@ has schema => (
     isa       => Str,
 );
 
-#pod =attr C<drop_table>
-#pod
-#pod If true, the table is dropped and a new one is created.
-#pod
-#pod =cut
+
+
+
+
+
 
 has drop_table => (
     is      => 'ro',
@@ -106,11 +102,10 @@ has drop_table => (
 );
 
 
-#pod =attr C<create_table>
-#pod
-#pod If true, a table will be created if it does not exist.
-#pod
-#pod =cut
+
+
+
+
 
 has create_table => (
     is      => 'ro',
@@ -118,13 +113,11 @@ has create_table => (
     default => 1,
 );
 
-#pod =attr C<primary>
-#pod
-#pod A single output column name or an array of output column names which
-#pod should be the primary key(s).  If not specified, no primary keys are
-#pod defined.
-#pod
-#pod =cut
+
+
+
+
+
 
 has primary => (
     is      => 'ro',
@@ -133,11 +126,11 @@ has primary => (
     default => sub { [] },
 );
 
-#pod =attr C<db_user>
-#pod
-#pod The name of the database user
-#pod
-#pod =cut
+
+
+
+
+
 
 has db_user => (
     is      => 'ro',
@@ -145,11 +138,11 @@ has db_user => (
     default => '',
 );
 
-#pod =attr C<db_pass>
-#pod
-#pod The database password
-#pod
-#pod =cut
+
+
+
+
+
 
 has db_pass => (
     is      => 'ro',
@@ -157,11 +150,11 @@ has db_pass => (
     default => '',
 );
 
-
 has _sth => (
     is       => 'rwp',
     init_arg => undef,
 );
+
 has _dbh => (
     is       => 'rwp',
     init_arg => undef,
@@ -173,12 +166,10 @@ has column_defs => (
     clearer  => 1,
     init_arg => undef,
     builder  => sub {
-
         my $self = shift;
 
         my @column_defs;
         for my $field ( @{ $self->output_fields } ) {
-
             push @column_defs,
               join( ' ',
                 $field,
@@ -188,17 +179,13 @@ has column_defs => (
 
         return join ', ', @column_defs;
     },
-
 );
 
-#pod =attr C<batch>
-#pod
-#pod The number of rows to write to the database at once.  This defaults to 100.
-#pod
-#pod If greater than 1, C<batch> rows are cached and then sent out in a
-#pod single transaction.  See L</Performance> for more information.
-#pod
-#pod =cut
+
+
+
+
+
 
 has batch => (
     is      => 'ro',
@@ -207,37 +194,67 @@ has batch => (
     coerce  => sub { $_[0] > 1 ? $_[0] : 0 },
 );
 
-#pod =attr C<dbitrace>
-#pod
-#pod A trace setting passed to  L<B<DBI>>.
-#pod
-#pod =cut
+
+
+
+
+
 
 has dbitrace => ( is => 'ro', );
 
-has _cache => (
+
+
+
+
+
+
+
+
+
+
+
+
+has queue => (
     is       => 'ro',
     init_arg => undef,
     default  => sub { [] },
 );
 
-before BUILD => sub {
+around '_build__nullified' => sub {
+    my $orig = shift;
+    my $self = $_[0];
 
-    my $self = shift;
+    my $nullified = $self->$orig( @_ );
 
-    $self->_set__map_types( {
-        S => 'text',
-        N => 'real',
-        I => 'integer'
-    } );
+    # defer to the caller
+    return $nullified if $self->has_nullify;
 
-    $self->_set__use_integer( 1 );
-    $self->_set__need_types( 1 );
+    # add all of the numeric fields
+    [ @{ $self->numeric_fields } ];
 
 };
 
-sub _table_exists {
+my %MapTypes = (
+    Pg      => { S => 'text', N => 'real', I => 'integer', B => 'boolean' },
+    SQLite  => { S => 'text', N => 'real', I => 'integer', B => 'integer' },
+    Default => { S => 'text', N => 'real', I => 'integer', B => 'integer' },
+);
 
+sub _map_types {
+    $MapTypes{ $_[0]->_dbi_driver } // $MapTypes{ Default }
+}
+
+
+
+
+
+
+
+
+
+sub to_bool { $_[0] ? 1 : 0 }
+
+sub _table_exists {
     my $self = shift;
 
     return
@@ -246,19 +263,24 @@ sub _table_exists {
 }
 
 sub _fq_table_name {
-
     my $self = shift;
 
     join( '.', ( $self->has_schema ? ( $self->schema ) : () ), $self->table );
 }
 
-#pod =begin pod_coverage
-#pod
-#pod =head3  setup
-#pod
-#pod =end pod_coverage
-#pod
-#pod =cut
+has _dsn_components => (
+    is       => 'lazy',
+    init_arg => undef,
+    builder  => sub {
+        my @dsn = DBI->parse_dsn( $_[0]->dsn )
+            or error( 'param', "unable to parse DSN: ", $_[0]->dsn );
+        \@dsn;
+    },
+);
+
+sub _dbi_driver {
+    $_[0]->_dsn_components->[1];
+}
 
 my %producer = (
     DB2       => 'DB2',
@@ -270,69 +292,77 @@ my %producer = (
     Sybase    => 'Sybase',
 );
 
-sub setup {
+has _producer => (
+    is       => 'lazy',
+    init_arg => undef,
+    builder  => sub {
+        my $dbi_driver = $_[0]->_dbi_driver;
+        $producer{$dbi_driver} || $dbi_driver;
+    },
+);
 
+
+
+
+
+
+sub setup {
     my $self = shift;
 
     return if $self->_dbh;
 
-    my @dsn = DBI->parse_dsn( $self->dsn )
-      or croak( "unable to parse DSN: ", $self->dsn );
-    my $dbi_driver = $dsn[1];
-
-    my $producer = $producer{$dbi_driver} || $dbi_driver;
-
     my %attr = (
-        AutoCommit => !$self->batch,
-        RaiseError => 1,
+        AutoCommit               => !$self->batch,
+        RaiseError               => 1,
+        PrintError               => 0,
+        'private_' . __PACKAGE__ => __FILE__ . __LINE__,
     );
 
     $attr{sqlite_allow_multiple_statements} = 1
-      if $dbi_driver eq 'SQLite';
+      if $self->_dbi_driver eq 'SQLite';
+
+    my $connect = $self->_cached ? 'connect_cached' : 'connect';
 
     $self->_set__dbh(
-        DBI->connect( $self->dsn, $self->db_user, $self->db_pass, \%attr ) )
-      or croak( 'error connection to ', $self->dsn, "\n" );
+        DBI->$connect( $self->dsn, $self->db_user, $self->db_pass, \%attr ) )
+      or error( 'connect', 'error connecting to ', $self->dsn, "\n" );
 
     $self->_dbh->trace( $self->dbitrace )
       if $self->dbitrace;
 
-    if ( $self->drop_table || ( $self->create_table && !$self->_table_exists ) )
-    {
+    if ( $self->drop_table || ( $self->create_table && !$self->_table_exists ) ) {
         my $tr = SQL::Translator->new(
             from => sub {
                 my $schema = $_[0]->schema;
                 my $table = $schema->add_table( name => $self->_fq_table_name )
-                  or croak $schema->error;
+                  or error( 'schema', $schema->error );
 
                 for my $field_name ( @{ $self->output_fields } ) {
-
                     $table->add_field(
                         name      => $field_name,
                         data_type => $self->output_types->{$field_name}
-                    ) or croak $table->error;
+                    ) or error( 'schema',  $table->error );
                 }
 
                 if ( @{ $self->primary } ) {
                     $table->primary_key( @{ $self->primary } )
-                      or croak $table->error;
+                      or error( 'schema', $table->error );
                 }
 
                 1;
             },
-            to             => $producer,
+            to             => $self->_producer,
             producer_args  => { no_transaction => 1 },
             add_drop_table => $self->drop_table && $self->_table_exists,
         );
 
-
         my $sql = $tr->translate
-          or croak $tr->error;
+          or error( 'schema', $tr->error );
 
         # print STDERR $sql;
         eval { $self->_dbh->do( $sql ); };
 
-        croak( "error in table creation: $@:\n$sql\n" )
+        error( 'create', { msg => "error in table creation: $@", payload => $sql } )
           if $@;
 
         $self->_dbh->commit if $self->batch;
@@ -350,51 +380,117 @@ sub setup {
     return;
 }
 
-sub _empty_cache {
 
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+sub flush {
     my $self = shift;
 
-    if ( @{ $self->_cache } ) {
+    my $queue = $self->queue;
 
+    if ( @{ $queue } ) {
+        my $last;
         eval {
-            $self->_sth->execute( @$_ ) foreach @{ $self->_cache };
-            $self->_dbh->commit;
+            $self->_sth->execute( @$last )
+              while $last = shift @{ $queue };
         };
 
-        # don't bother rolling back aborted transactions;
-        # individual inserts are independent of each other.
-        croak "Transaction aborted: $@" if $@;
+        my $error = $@;
+        $self->_dbh->commit;
 
-        @{ $self->_cache } = ();
+        if ( $error ) {
+            unshift @{ $queue }, $last;
+
+            my %query;
+            @query{ @{ $self->output_fields } } = @$last;
+            error( "insert", { msg => "Transaction aborted: $error", payload => \%query } );
+        }
     }
 
-    return;
+    1;
 }
 
-#pod =begin pod_coverage
-#pod
-#pod =head3 send
-#pod
-#pod =end pod_coverage
-#pod
-#pod =cut
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
 
 sub send {
-
     my $self = shift;
 
     if ( $self->batch ) {
-
-        push @{ $self->_cache }, [ @{ $_[0] }{ @{ $self->output_fields } } ];
-
-        $self->_empty_cache
-          if @{ $self->_cache } == $self->batch;
+        push @{ $self->queue }, [ @{ $_[0] }{ @{ $self->output_fields } } ];
+        $self->flush
+          if @{ $self->queue } == $self->batch;
 
     }
     else {
-        $self->_sth->execute( @{ $_[0] }{ @{ $self->output_fields } } );
+        eval {
+            $self->_sth->execute( @{ $_[0] }{ @{ $self->output_fields } } );
+        };
+        error( "insert", { msg => "record insertion failed: $@", payload => $_[0] } )
+          if $@;
     }
-
 }
 
 
@@ -407,60 +503,96 @@ after '_trigger_output_types' => sub {
 };
 
 
-#pod =begin pod_coverage
-#pod
-#pod =head3 close
-#pod
-#pod =end pod_coverage
-#pod
-#pod =cut
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
 
 sub close {
-
     my $self = shift;
 
-    $self->_empty_cache
+    $self->flush
       if $self->batch;
 
     $self->_dbh->disconnect
       if defined $self->_dbh;
+
+    1;
+}
+
+
+
+
+
+
+
+
+
+
+
+
+sub DEMOLISH {
+    my $self = shift;
+
+    warnings::warnif( 'Data::Record::Serialize::Encode::dbi::queue', __PACKAGE__.": record queue is not empty in object destruction" )
+        if @{ $self->queue };
+
+    $self->_dbh->disconnect
+      if defined $self->_dbh;
 }
 
+
 # these are required by the Sink/Encode interfaces but should never be
 # called in the ordinary run of things.
 
-#pod =begin pod_coverage
-#pod
-#pod =head3 say
-#pod
-#pod =head3 print
-#pod
-#pod =head3 encode
-#pod
-#pod =end pod_coverage
-#pod
-#pod =cut
 
 
-sub say    { croak }
-sub print  { croak }
-sub encode { croak }
 
-with 'Data::Record::Serialize::Role::Sink';
-with 'Data::Record::Serialize::Role::Encode';
 
 
+
+
+with 'Data::Record::Serialize::Role::EncodeAndSink';
+
 1;
 
+#
+# This file is part of Data-Record-Serialize
+#
+# This software is Copyright (c) 2017 by Smithsonian Astrophysical Observatory.
+#
+# This is free software, licensed under:
+#
+#   The GNU General Public License, Version 3, June 2007
+#
+
+__END__
+
 =pod
 
+=for :stopwords Diab Jerius Smithsonian Astrophysical Observatory Postgres
+
 =head1 NAME
 
 Data::Record::Serialize::Encode::dbi - store a record in a database
 
 =head1 VERSION
 
-version 0.11
+version 0.26
 
 =head1 SYNOPSIS
 
@@ -473,13 +605,13 @@ version 0.11
 =head1 DESCRIPTION
 
 B<Data::Record::Serialize::Encode::dbi> writes a record to a database using
-L<B<DBI>>.
+L<DBI>.
 
-It performs both the L<B<Data::Record::Serialize::Role::Encode>> and
-L<B<Data::Record::Serialize::Role::Sink>> roles.
+It performs both the L<Data::Record::Serialize::Role::Encode> and
+L<Data::Record::Serialize::Role::Sink> roles.
 
-B<You cannot construct this directly; you must use
-L<B<Data::Record::Serialize-E<gt>new>|Data::Record::Serialize/new>.>
+B<You cannot construct this directly>. You must use
+L<Data::Record::Serialize/new>.
 
 =head2 Types
 
@@ -489,6 +621,15 @@ Field types are recognized and converted to SQL types via the following map:
   N => 'real'
   I => 'integer'
 
+For Postgres, C<< B => 'boolean' >>. For other databases, C<< B => 'integer' >>.
+This encoder handles transformation of the input "truthy" Boolean value into
+a form appropriate for the database to ingest.
+
+=head2 NULL values
+
+By default numeric fields are set to C<NULL> if they are empty.  This
+can be changed by setting the C<nullify> attribute.
+
 =head2 Performance
 
 Records are by default written to the database in batches (see the
@@ -496,13 +637,179 @@ C<batch> attribute) to improve performance.  Each batch is performed
 as a single transaction.  If there is an error during the transaction,
 record insertions during the transaction are I<not> rolled back.
 
+=head2 Errors
+
+Transaction errors result in an exception in the
+C<Data::Record::Serialize::Error::Encode::dbi::insert> class. See
+L<Data::Record::Serialize::Error> for more information on exception
+objects.
+
 =head1 ATTRIBUTES
 
 These attributes are available in addition to the standard attributes
-defined for L<B<Data::Record::Serialize-E<gt>new>|Data::Record::Serialize/new>.
+defined for L<< Data::Record::Serialize::new|Data::Record::Serialize/new >>.
 
 =head2 C<dsn>
 
+The value passed to the constructor.
+
+=head2 C<table>
+
+The value passed to the constructor.
+
+=head2 C<schema>
+
+The value passed to the constructor.
+
+=head2 C<drop_table>
+
+The value passed to the constructor.
+
+=head2 C<create_table>
+
+The value passed to the constructor.
+
+=head2 C<primary>
+
+The value passed to the constructor.
+
+=head2 C<db_user>
+
+The value passed to the constructor.
+
+=head2 C<db_pass>
+
+The value passed to the constructor.
+
+=head2 C<batch>
+
+The value passed to the constructor.
+
+=head2 C<dbitrace>
+
+The value passed to the constructor.
+
+=head1 METHODS
+
+=head2 C<queue>
+
+  $queue = $obj->queue;
+
+The queue containing records not yet successfully transmitted
+to the database.  This is only of interest if L</batch> is not C<0>.
+
+Each element is an array containing values to be inserted into the database,
+in the same order as the fields in L<Data::Serialize/output_fields>.
+
+=head2 to_bool
+
+   $bool = $self->to_bool( $truthy );
+
+Convert a truthy value to something that the JSON encoders will recognize as a boolean.
+
+=head2 flush
+
+  $s->flush;
+
+Flush the queue of records to the database. It returns true if
+all of the records have been successfully written.
+
+If writing fails:
+
+=over
+
+=item *
+
+Writing of records ceases.
+
+=item *
+
+The failing record is left at the head of the queue.  This ensures
+that it is possible to retry writing the record.
+
+=item *
+
+an exception object (in the
+C<Data::Record::Serialize::Error::Encode::dbi::insert> class) will be
+thrown.  The failing record (in its final form after formatting, etc)
+is available via the object's C<payload> method.
+
+=back
+
+If a record fails to be written, it will still be queued for the next
+attempt at writing to the database.  If this behavior is undesired,
+make sure to remove it from the queue:
+
+  use Data::Dumper;
+
+  if ( ! eval { $output->flush } ) {
+      warn "$@", Dumper( $@->payload );
+      shift $output->queue->@*;
+  }
+
+As an example of completely flushing the queue while notifying of errors:
+
+  use Data::Dumper;
+
+  until ( eval { $output->flush } ) {
+      warn "$@", Dumper( $@->payload );
+      shift $output->queue->@*;
+  }
+
+=head2 send
+
+  $s->send( \%record );
+
+Send a record to the database.
+If there is an error, an exception object (with class
+C<Data::Record::Serialize::Error::Encode::dbi::insert>) will be
+thrown, and the record which failed to be written will be available
+via the object's C<payload> method.
+
+If in L</batch> mode, the record is queued for later transmission.
+When the number of records queued reaches that specified by the
+L</batch> attribute, the C<flush> method is called.  See L</flush> for
+more information on how errors are handled.
+
+=head2 close
+
+  $s->close;
+
+Close the database handle. If writing is batched, records in the queue
+are written to the database via L</flush>. An exception will be thrown
+if a record cannot be written.  See L</flush> for more details.
+
+As an example of draining the queue while notifying of errors:
+
+  use Data::Dumper;
+
+  until ( eval { $output->close } ) {
+      warn "$@", Dumper( $@->payload );
+      shift $output->queue->@*;
+  }
+
+=head2 DEMOLISH
+
+This method is called when the object is destroyed.  It closes the
+database handle B<but does not flush the record queue>.
+
+A warning is emitted if the record queue is not empty; turn off the
+C<Data::Record::Serialize::Encode::dbi::queue> warning to silence it.
+
+=for Pod::Coverage has_schema
+
+=for Pod::Coverage setup
+
+=for Pod::Coverage say
+  print
+  encode
+
+=head1 CONSTRUCTOR OPTIONS
+
+=over
+
+=item C<dsn>
+
 I<Required> The DBI Data Source Name (DSN) passed to B<L<DBI>>.  It
 may either be a string or an arrayref containing strings or arrayrefs,
 which should contain key-value pairs.  Elements in the sub-arrays are
@@ -517,86 +824,70 @@ is transformed to
 
 The standard prefix of C<dbi:> will be added if not present.
 
-=head2 C<table>
+=item C<cached>
+
+If true, the database connection is made with L<DBI::connect_cached|DBI/connect_cached> rather than
+L<DBI::connect|DBI/connect>
+
+=item C<table>
 
 I<Required> The name of the table in the database which will contain the records.
 It will be created if it does not exist.
 
-=head2 C<schema>
+=item C<schema>
 
 The schema to which the table belongs.  Optional.
 
-=head2 C<drop_table>
+=item C<drop_table>
 
 If true, the table is dropped and a new one is created.
 
-=head2 C<create_table>
+=item C<create_table>
 
 If true, a table will be created if it does not exist.
 
-=head2 C<primary>
+=item C<primary>
 
 A single output column name or an array of output column names which
 should be the primary key(s).  If not specified, no primary keys are
 defined.
 
-=head2 C<db_user>
+=item C<db_user>
 
 The name of the database user
 
-=head2 C<db_pass>
+=item C<db_pass>
 
 The database password
 
-=head2 C<batch>
+=item C<batch>
 
 The number of rows to write to the database at once.  This defaults to 100.
 
 If greater than 1, C<batch> rows are cached and then sent out in a
 single transaction.  See L</Performance> for more information.
 
-=head2 C<dbitrace>
+=item C<dbitrace>
 
-A trace setting passed to  L<B<DBI>>.
+A trace setting passed to  L<DBI>.
 
-=begin pod_coverage
+=back
 
-=head3 has_schema
+=head1 SUPPORT
 
-=end pod_coverage
+=head2 Bugs
 
-=begin pod_coverage
+Please report any bugs or feature requests to bug-data-record-serialize@rt.cpan.org  or through the web interface at: https://rt.cpan.org/Public/Dist/Display.html?Name=Data-Record-Serialize
 
-=head3 setup
+=head2 Source
 
-=end pod_coverage
+Source is available at
 
-=begin pod_coverage
+  https://gitlab.com/djerius/data-record-serialize
 
-=head3 send
+and may be cloned from
 
-=end pod_coverage
-
-=begin pod_coverage
-
-=head3 close
-
-=end pod_coverage
-
-=begin pod_coverage
-
-=head3 say
-
-=head3 print
-
-=head3 encode
-
-=end pod_coverage
-
-=head1 BUGS AND LIMITATIONS
-
-You can make new bug reports, and view existing ones, through the
-web interface at L<https://rt.cpan.org/Public/Dist/Display.html?Name=Data-Record-Serialize>.
+  https://gitlab.com/djerius/data-record-serialize.git
 
 =head1 SEE ALSO
 
@@ -623,45 +914,3 @@ This is free software, licensed under:
   The GNU General Public License, Version 3, June 2007
 
 =cut
-
-__END__
-
-#pod =head1 SYNOPSIS
-#pod
-#pod     use Data::Record::Serialize;
-#pod
-#pod     my $s = Data::Record::Serialize->new( encode => 'sqlite', ... );
-#pod
-#pod     $s->send( \%record );
-#pod
-#pod =head1 DESCRIPTION
-#pod
-#pod B<Data::Record::Serialize::Encode::dbi> writes a record to a database using
-#pod L<B<DBI>>.
-#pod
-#pod It performs both the L<B<Data::Record::Serialize::Role::Encode>> and
-#pod L<B<Data::Record::Serialize::Role::Sink>> roles.
-#pod
-#pod B<You cannot construct this directly; you must use
-#pod L<B<Data::Record::Serialize-E<gt>new>|Data::Record::Serialize/new>.>
-#pod
-#pod =head2 Types
-#pod
-#pod Field types are recognized and converted to SQL types via the following map:
-#pod
-#pod   S => 'text'
-#pod   N => 'real'
-#pod   I => 'integer'
-#pod
-#pod
-#pod =head2 Performance
-#pod
-#pod Records are by default written to the database in batches (see the
-#pod C<batch> attribute) to improve performance.  Each batch is performed
-#pod as a single transaction.  If there is an error during the transaction,
-#pod record insertions during the transaction are I<not> rolled back.
-#pod
-#pod =head1 ATTRIBUTES
-#pod
-#pod These attributes are available in addition to the standard attributes
-#pod defined for L<B<Data::Record::Serialize-E<gt>new>|Data::Record::Serialize/new>.
