@@ -4,49 +4,35 @@ package Data::Record::Serialize::Encode::rdb;
 
 use Moo::Role;
 
-our $VERSION = '0.11'; # TRIAL
-
-before BUILD => sub {
-
-    my $self = shift;
-
-    $self->_set__use_integer( 0 );
-    $self->_set__map_types( { N => 'N', I => 'N', S => 'S' } );
-
-    $self->_set__needs_eol( 1 );
-
-};
+our $VERSION = '0.26'; # TRIAL
 
 use namespace::clean;
 
-#pod =begin pod_coverage
-#pod
-#pod =head3 setup
-#pod
-#pod =end pod_coverage
-#pod
-#pod =cut
+sub _needs_eol { 1 }
+sub _map_types { { N => 'N', I => 'N', S => 'S'  } }
+
+
+
+
+
+
 
 sub setup {
-
     my $self = shift;
 
     $self->say( join( "\t", @{ $self->output_fields } ) );
     $self->say( join( "\t", @{ $self->output_types }{ @{ $self->output_fields } } ) );
-
 }
 
-#pod =begin pod_coverage
-#pod
-#pod =head3 encode
-#pod
-#pod =end pod_coverage
-#pod
-#pod =cut
+
+
+
+
 
 sub encode {
     my $self = shift;
 
+    no warnings 'uninitialized';
     join( "\t", @{ $_[0] }{ @{ $self->output_fields } } );
 }
 
@@ -54,15 +40,29 @@ with 'Data::Record::Serialize::Role::Encode';
 
 1;
 
+#
+# This file is part of Data-Record-Serialize
+#
+# This software is Copyright (c) 2017 by Smithsonian Astrophysical Observatory.
+#
+# This is free software, licensed under:
+#
+#   The GNU General Public License, Version 3, June 2007
+#
+
+__END__
+
 =pod
 
+=for :stopwords Diab Jerius Smithsonian Astrophysical Observatory
+
 =head1 NAME
 
 Data::Record::Serialize::Encode::rdb - encoded a record as /rdb
 
 =head1 VERSION
 
-version 0.11
+version 0.26
 
 =head1 SYNOPSIS
 
@@ -77,29 +77,32 @@ version 0.11
 B<Data::Record::Serialize::Encode::rdb> encodes a record as
 L<RDB|http://compbio.soe.ucsc.edu/rdb>.
 
-It performs the L<B<Data::Record::Serialize::Role::Encode>> role.
+It performs the L<Data::Record::Serialize::Role::Encode> role.
 
-=begin pod_coverage
+=for Pod::Coverage setup
 
-=head3 setup
-
-=end pod_coverage
-
-=begin pod_coverage
-
-=head3 encode
-
-=end pod_coverage
+=for Pod::Coverage encode
 
 =head1 INTERFACE
 
 There are no additional attributes which may be passed to
-L<B<Data::Record::Serialize-E<gt>new>|Data::Record::Serialize/new>:
+L<Data::Record::Serialize-E<gt>new>|Data::Record::Serialize/new>.
 
-=head1 BUGS AND LIMITATIONS
+=head1 SUPPORT
 
-You can make new bug reports, and view existing ones, through the
-web interface at L<https://rt.cpan.org/Public/Dist/Display.html?Name=Data-Record-Serialize>.
+=head2 Bugs
+
+Please report any bugs or feature requests to bug-data-record-serialize@rt.cpan.org  or through the web interface at: https://rt.cpan.org/Public/Dist/Display.html?Name=Data-Record-Serialize
+
+=head2 Source
+
+Source is available at
+
+  https://gitlab.com/djerius/data-record-serialize
+
+and may be cloned from
+
+  https://gitlab.com/djerius/data-record-serialize.git
 
 =head1 SEE ALSO
 
@@ -126,26 +129,3 @@ This is free software, licensed under:
   The GNU General Public License, Version 3, June 2007
 
 =cut
-
-__END__
-
-#pod =head1 SYNOPSIS
-#pod
-#pod     use Data::Record::Serialize;
-#pod
-#pod     my $s = Data::Record::Serialize->new( encode => 'rdb', ... );
-#pod
-#pod     $s->send( \%record );
-#pod
-#pod =head1 DESCRIPTION
-#pod
-#pod B<Data::Record::Serialize::Encode::rdb> encodes a record as
-#pod L<RDB|http://compbio.soe.ucsc.edu/rdb>.
-#pod
-#pod It performs the L<B<Data::Record::Serialize::Role::Encode>> role.
-#pod
-#pod
-#pod =head1 INTERFACE
-#pod
-#pod There are no additional attributes which may be passed to
-#pod L<B<Data::Record::Serialize-E<gt>new>|Data::Record::Serialize/new>:
