@@ -6,19 +6,14 @@ use Moo::Role;
 
 use namespace::clean;
 
-our $VERSION = '0.11'; # TRIAL
+our $VERSION = '0.26'; # TRIAL
+
+
+
+
+
+
 
-#pod =begin pod_coverage
-#pod
-#pod =head3 print
-#pod
-#pod =head3 say
-#pod
-#pod =head3 close
-#pod
-#pod =end pod_coverage
-#pod
-#pod =cut
 
 sub print { }
 sub say   { }
@@ -29,15 +24,29 @@ with 'Data::Record::Serialize::Role::Sink';
 
 1;
 
+#
+# This file is part of Data-Record-Serialize
+#
+# This software is Copyright (c) 2017 by Smithsonian Astrophysical Observatory.
+#
+# This is free software, licensed under:
+#
+#   The GNU General Public License, Version 3, June 2007
+#
+
+__END__
+
 =pod
 
+=for :stopwords Diab Jerius Smithsonian Astrophysical Observatory
+
 =head1 NAME
 
 Data::Record::Serialize::Sink::null - send output to nowhere.
 
 =head1 VERSION
 
-version 0.11
+version 0.26
 
 =head1 SYNOPSIS
 
@@ -51,22 +60,27 @@ version 0.11
 
 B<Data::Record::Serialize::Sink::stream> sends data to the bitbucket.
 
-It performs the L<B<Data::Record::Serialize::Role::Sink>> role.
+It performs the L<Data::Record::Serialize::Role::Sink> role.
 
-=begin pod_coverage
+=for Pod::Coverage print
+ say
+ close
 
-=head3 print
+=head1 SUPPORT
 
-=head3 say
+=head2 Bugs
 
-=head3 close
+Please report any bugs or feature requests to bug-data-record-serialize@rt.cpan.org  or through the web interface at: https://rt.cpan.org/Public/Dist/Display.html?Name=Data-Record-Serialize
 
-=end pod_coverage
+=head2 Source
 
-=head1 BUGS AND LIMITATIONS
+Source is available at
 
-You can make new bug reports, and view existing ones, through the
-web interface at L<https://rt.cpan.org/Public/Dist/Display.html?Name=Data-Record-Serialize>.
+  https://gitlab.com/djerius/data-record-serialize
+
+and may be cloned from
+
+  https://gitlab.com/djerius/data-record-serialize.git
 
 =head1 SEE ALSO
 
@@ -93,19 +107,3 @@ This is free software, licensed under:
   The GNU General Public License, Version 3, June 2007
 
 =cut
-
-__END__
-
-#pod =head1 SYNOPSIS
-#pod
-#pod     use Data::Record::Serialize;
-#pod
-#pod     my $s = Data::Record::Serialize->new( sink => 'null', ... );
-#pod
-#pod     $s->send( \%record );
-#pod
-#pod =head1 DESCRIPTION
-#pod
-#pod B<Data::Record::Serialize::Sink::stream> sends data to the bitbucket.
-#pod
-#pod It performs the L<B<Data::Record::Serialize::Role::Sink>> role.
