@@ -5,7 +5,9 @@ package Data::Record::Serialize::Sink::stream;
 
 use Moo::Role;
 
-our $VERSION = '0.11'; # TRIAL
+use Data::Record::Serialize::Error { errors => [ '::create' ] }, -all;
+
+our $VERSION = '0.26'; # TRIAL
 
 use IO::File;
 
@@ -15,33 +17,23 @@ has output => (
     is      => 'ro',
 );
 
-
 has fh => (
-
     is => 'lazy',
-
     builder => sub {
         my $self = shift;
-
         return ( ! defined $self->output || $self->output eq '-' )
           ? \*STDOUT
           : ( IO::File->new( $self->output, 'w' )
-              or croak( "unable to create @{[ $self->output ]}\n" ) );
+              or error( '::create', "unable to create @{[ $self->output ]}" ) );
     },
-
 );
 
-#pod =begin pod_coverage
-#pod
-#pod =head3 print
-#pod
-#pod =head3 say
-#pod
-#pod =head3 close
-#pod
-#pod =end pod_coverage
-#pod
-#pod =cut
+
+
+
+
+
+
 
 sub print { shift->fh->print( @_ ) }
 sub say   { shift->fh->say( @_ ) }
@@ -51,15 +43,29 @@ with 'Data::Record::Serialize::Role::Sink';
 
 1;
 
+#
+# This file is part of Data-Record-Serialize
+#
+# This software is Copyright (c) 2017 by Smithsonian Astrophysical Observatory.
+#
+# This is free software, licensed under:
+#
+#   The GNU General Public License, Version 3, June 2007
+#
+
+__END__
+
 =pod
 
+=for :stopwords Diab Jerius Smithsonian Astrophysical Observatory
+
 =head1 NAME
 
 Data::Record::Serialize::Sink::stream - output encoded data to a stream.
 
 =head1 VERSION
 
-version 0.11
+version 0.26
 
 =head1 SYNOPSIS
 
@@ -74,22 +80,16 @@ version 0.11
 B<Data::Record::Serialize::Sink::stream> outputs encoded data to a
 file handle.
 
-It performs the L<B<Data::Record::Serialize::Role::Sink>> role.
+It performs the L<Data::Record::Serialize::Role::Sink> role.
 
-=begin pod_coverage
-
-=head3 print
-
-=head3 say
-
-=head3 close
-
-=end pod_coverage
+=for Pod::Coverage print
+ say
+ close
 
 =head1 INTERFACE
 
 The following attributes may be passed to
-L<B<Data::Record::Serialize-E<gt>new>|Data::Record::Serialize/new>:
+L<Data::Record::Serialize-E<gt>new>|Data::Record::Serialize/new>:
 
 =over
 
@@ -107,10 +107,21 @@ A file handle.
 If neither is specified, output is written to the standard output
 stream.
 
-=head1 BUGS AND LIMITATIONS
+=head1 SUPPORT
 
-You can make new bug reports, and view existing ones, through the
-web interface at L<https://rt.cpan.org/Public/Dist/Display.html?Name=Data-Record-Serialize>.
+=head2 Bugs
+
+Please report any bugs or feature requests to bug-data-record-serialize@rt.cpan.org  or through the web interface at: https://rt.cpan.org/Public/Dist/Display.html?Name=Data-Record-Serialize
+
+=head2 Source
+
+Source is available at
+
+  https://gitlab.com/djerius/data-record-serialize
+
+and may be cloned from
+
+  https://gitlab.com/djerius/data-record-serialize.git
 
 =head1 SEE ALSO
 
@@ -137,42 +148,3 @@ This is free software, licensed under:
   The GNU General Public License, Version 3, June 2007
 
 =cut
-
-__END__
-
-#pod =head1 SYNOPSIS
-#pod
-#pod     use Data::Record::Serialize;
-#pod
-#pod     my $s = Data::Record::Serialize->new( sink => 'stream', ... );
-#pod
-#pod     $s->send( \%record );
-#pod
-#pod =head1 DESCRIPTION
-#pod
-#pod B<Data::Record::Serialize::Sink::stream> outputs encoded data to a
-#pod file handle.
-#pod
-#pod It performs the L<B<Data::Record::Serialize::Role::Sink>> role.
-#pod
-#pod
-#pod =head1 INTERFACE
-#pod
-#pod The following attributes may be passed to
-#pod L<B<Data::Record::Serialize-E<gt>new>|Data::Record::Serialize/new>:
-#pod
-#pod =over
-#pod
-#pod =item C<output>
-#pod
-#pod The name of an output file or a reference to a scalar to which the records will be written.
-#pod C<output> may be set to C<-> to indicate output to the standard output stream.
-#pod
-#pod =item C<fh>
-#pod
-#pod A file handle.
-#pod
-#pod =back
-#pod
-#pod If neither is specified, output is written to the standard output
-#pod stream.
