@@ -5,12 +5,12 @@ package Data::Record::Serialize::Types;
 use strict;
 use warnings;
 
-our $VERSION = '0.11'; # TRIAL
+our $VERSION = '0.26'; # TRIAL
 
 use Type::Utils -all;
-use Types::Standard -types;
+use Types::Standard qw( ArrayRef Str Enum );
 use Type::Library -base,
-  -declare => qw[ ArrayOfStr ];
+  -declare => qw[ ArrayOfStr SerializeType ];
 
 use namespace::clean;
 
@@ -20,6 +20,8 @@ declare ArrayOfStr,
 coerce ArrayOfStr,
   from Str, q { [ $_ ] };
 
+declare SerializeType,
+  as Enum[ qw( N I S B) ];
 
 #
 # This file is part of Data-Record-Serialize
@@ -37,18 +39,31 @@ __END__
 
 =pod
 
+=for :stopwords Diab Jerius Smithsonian Astrophysical Observatory
+
 =head1 NAME
 
 Data::Record::Serialize::Types - Types for Data::Record::Serialize
 
 =head1 VERSION
 
-version 0.11
+version 0.26
 
-=head1 BUGS AND LIMITATIONS
+=head1 SUPPORT
 
-You can make new bug reports, and view existing ones, through the
-web interface at L<https://rt.cpan.org/Public/Dist/Display.html?Name=Data-Record-Serialize>.
+=head2 Bugs
+
+Please report any bugs or feature requests to bug-data-record-serialize@rt.cpan.org  or through the web interface at: https://rt.cpan.org/Public/Dist/Display.html?Name=Data-Record-Serialize
+
+=head2 Source
+
+Source is available at
+
+  https://gitlab.com/djerius/data-record-serialize
+
+and may be cloned from
+
+  https://gitlab.com/djerius/data-record-serialize.git
 
 =head1 SEE ALSO
 
